#!/bin/sh
# Copyright (c) 2019 Veritas Technologies LLC. All Rights Reserved 
echo "************************************************************************"
echo "*        VERITAS BACKUP EXEC FOR LINUX RALUS PATCH PROGRAM       *"
echo "************************************************************************"
echo "* Copyright (c) 2019 Veritas Technologies LLC. All rights reserved     *"

OSTYPE=`uname -s`
if [ $OSTYPE = 'Linux' ]
then
	LOGUSER=`id -un`
        if [ `cat /etc/issue | grep 'Debian\|Ubuntu' | wc -l` = 1 ]
        then
                if [ `which dpkg-query | wc -l` = 1 ]
                then
        	        RALUSINSTALLED=`dpkg-query -l | grep vrtsralus | wc -l`
                fi
        else
                RALUSINSTALLED=`rpm -q -a | grep VRTSralus | wc -l`
        fi
        if [ `file /opt/VRTSralus/bin/beremote | grep 64-bit | wc -l` = 1 ]
	then
		RALUSPATCHDIR="Linux64"
	else
		RALUSPATCHDIR="Linux"
	fi
else
	echo "Unsupported OS version...exiting."
	exit
fi
if [ $LOGUSER != 'root' ]
then
	echo "You have to be root to run this script...exiting"
	exit
fi
if [ $RALUSINSTALLED = 0 ]
then
	echo "RALUS is not installed on this system...exiting"
	exit
fi

if [ ! -f /var/VRTSralus/ralus.ver ]
then
	echo "The ralus.ver file does not exist...exiting"
	exit
fi
RALUSVERTEST=`cat /var/VRTSralus/ralus.ver | grep ralus | wc -l`
if [ $RALUSVERTEST = 0 ]
then
	echo "This patch only applies to RALUS shipped with Backup Exec  ...exiting"
	exit
fi

RALUSVERSION=`cat /var/VRTSralus/ralus.ver | grep ralus | cut -d= -f2 | cut -d. -f1`

if [ $RALUSVERSION != '1200' ]
then
      echo "Not a valid Backup Exec version to upgrade from.... exiting"
      exit
fi

RALVER=`cat /var/VRTSralus/ralus.ver | grep ralus | cut -d= -f2 | cut -d. -f2`

echo

ISSP=`cat ./ralus.ver | grep ralus | grep SP | wc -l`

PATCHVERSION=`cat ./ralus.ver | grep ralus | cut -d= -f2 | cut -d. -f2`
if [ $PATCHVERSION -le $RALVER ]
then
      if [ $ISSP -eq 0 ]
      then
            echo "Your version of RALUS is newer or equal to the patch you are trying to install...exiting."
            exit
      fi
fi

RALUSNEWPATCHVERSION=`cat ./ralus.ver | grep ralus | cut -d= -f2 | cut -d. -f1`

echo "Current Backup Exec RALUS base version installed on system : $RALUSVERSION"
echo "Current Backup Exec RALUS patch version installed on this system : $RALUSVERSION.$RALVER"

if [ $PATCHVERSION = $RALVER ]
then
    echo "RALUS patch version $RALUSVERSION.$PATCHVERSION already installed on system....exiting."
    exit
fi

echo "Installing RALUS patch $RALUSNEWPATCHVERSION.$PATCHVERSION for $RALUSPATCHDIR..."
echo
echo "Stopping RALUS service..."
	/etc/init.d/VRTSralus.init stop
	sleep 5
chmod 750 /var/VRTSralus/ralus.ver
cp ./ralus.ver /var/VRTSralus
cd ./$RALUSPATCHDIR
tar cf - * | (cd /opt/VRTSralus;tar xf -)

#Uninstall symbdsnap first if old driver present and then install new driver else the same does not get re-installed and keeps using old driver on SUSE
DRIVERINSTALLED=`rpm -q -a | grep symbdsnap | wc -l`
if [ $DRIVERINSTALLED = 1 ]; then
echo "Uninstalling old symbdsnap driver...."
rpm -e --nodeps symbdsnap
fi


#Below statement will upgrade AOFO-L driver if present , if not supported this statement will do no harm since driver will give error message as not supported
#No need to do any specific error checking here. Directory will be Linux/scripts or Linux64/scripts
#etrack 3306945
if [ -f "./scripts/Veritas_symbdsnap.bin" ]; then
echo "Newer AOFO-L driver present for RALUS...updating"
./scripts/Veritas_symbdsnap.bin  
fi

chown -R root:beoper /opt/VRTSralus

#check if particular fix exists and rename as it is needed by ralus to function properly
if [ -f "/opt/VRTSralus/VRTSvxms/lib/map/libext2fs.so" ]; then
   echo "Found libext2fs.so renaming to libext2fs.."
   echo
   mv /opt/VRTSralus/VRTSvxms/lib/map/libext2fs.so /opt/VRTSralus/VRTSvxms/lib/map/libext2fs
   chmod 550 /opt/VRTSralus/VRTSvxms/lib/map/libext2fs
   echo "Renamed libext2fs.so to libext2fs.."
fi

#remove old acetao libraries as new ones do not have the so.6 extension
if [ -f "/opt/VRTSralus/bin/libvxACE.so.6" ]; then
   rm -rf /opt/VRTSralus/bin/libvxACE.so.6
fi

if [ -f "/opt/VRTSralus/bin/libvxTAO.so.6" ]; then
   rm -rf /opt/VRTSralus/bin/libvxTAO.so.6
fi

if [ -f "/opt/VRTSralus/bin/libvxTAO_AnyTypeCode.so.6" ]; then
   rm -rf /opt/VRTSralus/bin/libvxTAO_AnyTypeCode.so.6
fi

if [ -f "/opt/VRTSralus/bin/libcurl.so.4.4.0" ]; then
   rm -rf /opt/VRTSralus/bin/libcurl.so.4.4.0
fi

if [ -f "/opt/VRTSralus/bin/libxml2.so.2.9.4" ]; then
   rm -rf /opt/VRTSralus/bin/libxml2.so.2.9.4
fi

if [ $OSTYPE = 'Linux' -a -f /etc/oratab ]; then
    ORA_HOME=`awk -F: '/^[^#:]+:.+:[YN]/ { print $2; exit}' /etc/oratab`
    if [ "$ORA_HOME" != "" -a -f $ORA_HOME/bin/dbstart ]; then
        ORA_OWNER=`ls -l $ORA_HOME/bin/dbstart | awk '{print $3}'`
        if [ "$ORA_OWNER" != "" ]; then
            ORA_GROUP=`id -G $ORA_OWNER | sed 's/ /,/g'`
                if [ "$ORA_GROUP" != "" ]; then
                    usermod -G $ORA_GROUP,beoper $ORA_OWNER
                fi
        fi
     fi
fi

cd /
echo "Finished installing RALUS patch...restarting RALUS services..."
	/etc/init.d/VRTSralus.init start
